pub enum RevokeToken {
AccessToken(AccessToken),
RefreshToken(RefreshToken),
}Expand description
Represents a token that can be revoked, which can be either an access token or a refresh token.
Variants
AccessToken(AccessToken)
RefreshToken(RefreshToken)
Implementations
Sourceimpl RevokeToken
impl RevokeToken
Sourcepub fn new_access_token(token: &str) -> Self
pub fn new_access_token(token: &str) -> Self
Creates a RevokeToken instance for an access token.
Sourcepub fn new_refresh_token(token: &str) -> Self
pub fn new_refresh_token(token: &str) -> Self
Creates a RevokeToken instance for a refresh token.
pub fn access_token(&self) -> Option<&AccessToken>
pub fn refresh_token(&self) -> Option<&RefreshToken>